@@ -348,7 +348,7 @@ pipe_filter_ii_execute (const char *progname,
             if (buf != NULL)
               {
                 /* Writing to a pipe in non-blocking mode is tricky: The
-                   write() call may fail with EAGAIN, simply because suffcient
+                   write() call may fail with EAGAIN, simply because sufficient
                    space is not available in the pipe. See POSIX:2008
                    <http://pubs.opengroup.org/onlinepubs/9699919799/functions/write.html>.
                    This happens actually on AIX and IRIX, when bufsize >= 8192
