@@ -299,9 +299,9 @@ assert_eq (astr as, const char *s)
 }
 
 /* Stub to make xalloc_die happy. */
-void _Noreturn zile_exit (int doabort);
+void zile_exit (int doabort);
 
-void
+_Noreturn void
 zile_exit (int doabort _GL_UNUSED_PARAMETER)
 {
   exit (EXIT_CRASH);
