@@ -1,6 +1,6 @@
 /* History facility functions
 
-   Copyright (c) 2004, 2008, 2010, 2011 Free Software Foundation, Inc.
+   Copyright (c) 2004, 2008, 2010-2011 Free Software Foundation, Inc.
 
    This file is part of GNU Zile.
 
@@ -38,14 +38,6 @@ History *history_new (void)
   return XZALLOC (History);
 }
 
-void
-free_history (History * hp)
-{
-  if (hp->elements)
-    gl_list_free (hp->elements);
-  free (hp);
-}
-
 void
 add_history_element (History * hp, const char *string)
 {
@@ -53,10 +45,10 @@ add_history_element (History * hp, const char *string)
 
   if (!hp->elements)
     hp->elements = gl_list_create_empty (GL_LINKED_LIST,
-                                         NULL, NULL, (gl_listelement_dispose_fn) free, true);
+                                         NULL, NULL, NULL, true);
   else
     last = (const char *) gl_list_get_at (hp->elements, gl_list_size (hp->elements) - 1);
-  if (!last || STRNEQ (last, string))
+  if (!last || !STREQ (last, string))
     gl_list_add_last (hp->elements, xstrdup (string));
 }
 
