@@ -1,6 +1,6 @@
 /* Registers facility functions
 
-   Copyright (c) 2001, 2003, 2004, 2005, 2006, 2008, 2009, 2010, 2011 Free Software Foundation, Inc.
+   Copyright (c) 2001, 2003-2006, 2008-2011 Free Software Foundation, Inc.
 
    This file is part of GNU Zile.
 
@@ -31,7 +31,7 @@
 
 #define NUM_REGISTERS	256
 
-static astr regs[NUM_REGISTERS];
+static estr regs[NUM_REGISTERS];
 
 DEFUN_ARGS ("copy-to-register", copy_to_register,
             INT_ARG (reg))
@@ -43,31 +43,23 @@ Copy region into register @i{register}.
   else
     {
       minibuf_write ("Copy to register: ");
-      reg = getkey ();
+      reg = getkey (GETKEY_DEFAULT);
     }
 
   if (reg == KBD_CANCEL)
     ok = FUNCALL (keyboard_quit);
   else
     {
-      Region * rp = region_new ();
-
       minibuf_clear ();
       if (reg < 0)
         reg = 0;
       reg %= NUM_REGISTERS; /* Nice numbering relies on NUM_REGISTERS
                                being a power of 2. */
 
-      if (!calculate_the_region (rp))
+      if (warn_if_no_mark ())
         ok = leNIL;
       else
-        {
-          if (regs[reg] != NULL)
-            astr_delete (regs[reg]);
-          regs[reg] = copy_text_block (get_region_start (rp), get_region_size (rp));
-        }
-
-      free (rp);
+        regs[reg] = get_buffer_region (cur_bp, calculate_the_region ());
     }
 }
 END_DEFUN
@@ -77,10 +69,7 @@ static int regnum;
 static bool
 insert_register (void)
 {
-  undo_save (UNDO_REPLACE_BLOCK, get_buffer_pt (cur_bp), 0, astr_len (regs[regnum]));
-  undo_nosave = true;
-  insert_astr (regs[regnum]);
-  undo_nosave = false;
+  insert_estr (regs[regnum]);
   return true;
 }
 
@@ -98,7 +87,7 @@ Puts point before and mark after the inserted text.
   else
     {
       minibuf_write ("Insert register: ");
-      reg = getkey ();
+      reg = getkey (GETKEY_DEFAULT);
     }
 
   if (reg == KBD_CANCEL)
@@ -108,14 +97,14 @@ Puts point before and mark after the inserted text.
       minibuf_clear ();
       reg %= NUM_REGISTERS;
 
-      if (regs[reg] == NULL)
+      if (regs[reg].as == NULL)
         {
           minibuf_error ("Register does not contain text");
           ok = leNIL;
         }
       else
         {
-          set_mark_interactive ();
+          FUNCALL (set_mark_command);
           regnum = reg;
           execute_with_uniarg (true, uniarg, insert_register, NULL);
           FUNCALL (exchange_point_and_mark);
@@ -128,33 +117,21 @@ END_DEFUN
 static void
 write_registers_list (va_list ap _GL_UNUSED_PARAMETER)
 {
-  size_t i;
-
-  for (i = 0; i < NUM_REGISTERS; ++i)
-    if (regs[i] != NULL)
+  for (size_t i = 0; i < NUM_REGISTERS; ++i)
+    if (regs[i].as != NULL)
       {
-        const char *s = astr_cstr (regs[i]);
-        astr as = astr_new ();
-        size_t len;
-
-        if (isprint (i))
-          astr_afmt (as, "%c", i);
-        else
-          astr_afmt (as, "\\%o", i);
-
+        const char *s = astr_cstr (regs[i].as);
         while (*s == ' ' || *s == '\t' || *s == '\n')
           s++;
-        len = MIN (20, MAX (0, ((int) get_window_ewidth (cur_wp)) - 6)) + 1;
+        size_t len = MIN (20, MAX (0, ((int) get_window_ewidth (cur_wp)) - 6)) + 1;
 
-        bprintf ("Register %s contains ", astr_cstr (as));
+        bprintf ("Register %s contains ", astr_cstr (astr_fmt (isprint (i) ? "%c" : "\\%o", i)));
         if (strlen (s) > 0)
           bprintf ("text starting with\n    %.*s\n", len, s);
-        else if (s != astr_cstr (regs[i]))
+        else if (s != astr_cstr (regs[i].as))
           bprintf ("whitespace\n");
         else
           bprintf ("the empty string\n");
-
-        astr_delete (as);
       }
 }
 
